@@ -145,6 +145,7 @@ tLoadProc mLoad_Define;
 tLoadProc mLoad_Expr;
 tLoadProc mLoad_For;
 tLoadProc mLoad_If;
+tLoadProc mLoad_Include;
 tLoadProc mLoad_Unknown;
 tLoadProc mLoad_While;
 
@@ -171,7 +172,7 @@ tpLoadProc apLoadProc[ 20 ] = {
     /* EXPR      */ &mLoad_Expr,
     /* FOR       */ &mLoad_For,
     /* IF        */ &mLoad_If,
-    /* INCLUDE   */ &mLoad_Expr,
+    /* INCLUDE   */ &mLoad_Include,
     /* INVOKE    */ &mLoad_Unknown /*default*/,
     /* SELECT    */ &mLoad_Bogus   /*dynamic*/,
     /* TEXT      */ &mLoad_Unknown /*default*/,
