@@ -89,7 +89,7 @@ whichFunc( tTemplate* pT, tMacro* pMac, const char** ppzScan )
              *  Make sure we matched to the end of the token.
              */
             if (ISNAMECHAR( pzFuncName[pNT->cmpLen] ))
-                return FTYP_BOGUS;
+                break;
 
             /*
              *  Advance the scanner past the macro name.
