@@ -1,6 +1,6 @@
 
 /*
- *  $Id: autoopts.c,v 2.35 2001/10/13 18:51:02 bkorb Exp $
+ *  $Id: autoopts.c,v 2.36 2001/11/21 06:00:41 bkorb Exp $
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -1484,7 +1484,7 @@ const char*
 optionVersion()
 {
     static const char zVersion[] =
-        STR( AO_ANNOUNCE_LEVEL );
+        STR( AO_CURRENT.AO_REVISION );
 
     return zVersion;
 }
