@@ -5,14 +5,14 @@
 /* Author:	       Gary V. Vaughan <gvv@techie.com>
  * Maintainer:	       Gary V. Vaughan <gvv@techie.com>
  * Created:	       Thu Apr 22 23:13:34 1999
- * Last Modified:      Thu Sep 23 23:03:15 1999
- *            by:      Gary V. Vaughan <gvv@techie.com>
+ * Last Modified:      Wed Aug  8 12:22:14 2001
+ *            by:      Gary V. Vaughan <gary@gnu.org>
  * ---------------------------------------------------------------------
- * @(#) $Id: format.c,v 1.7 2001/05/05 02:59:53 bkorb Exp $
+ * @(#) $Id: format.c,v 1.10 2001/08/12 03:07:36 bkorb Exp $
  * ---------------------------------------------------------------------
  */
 
-/* Copyright (C) 1999 Gary V. Vaughan */
+/* Copyright (C) 1999, 2001 Gary V. Vaughan */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -191,6 +191,7 @@ fetch_argv_long (pparser, argv, index)
     long result		= 0L;
     unsigned flags  	= fetch_zero_defaulted_uint(pparser, "flags");
 
+#if INDIRECT_LONG
     /* parser read '*', and should get value from argument vector */
     if (ISSET(flags, SNV_FLAG_LONG))
     {
@@ -199,6 +200,7 @@ fetch_argv_long (pparser, argv, index)
 	result = *(long*)argv[index];
     }
     else
+#endif
     {
 	/* Any other integral type can fit in a pointer, so we stored
 	   the data directly in the word. (we don't support long long
@@ -218,6 +220,7 @@ fetch_argv_ulong (pparser, argv, index)
     unsigned long result = 0L;
     unsigned flags  	 = fetch_zero_defaulted_uint(pparser, "flags");
 
+#if INDIRECT_LONG
     /* parser read '*', and should get value from argument vector */
     if (ISSET(flags, SNV_FLAG_LONG))
     {
@@ -226,6 +229,7 @@ fetch_argv_ulong (pparser, argv, index)
 	result = *(unsigned long*)argv[index];
     }
     else
+#endif
     {
 	/* Any other integral type can fit in a pointer, so we stored
 	   the data directly in the word. (we don't support long long
@@ -607,7 +611,7 @@ format_number (pparser, stream, ppformat, argv, pargc,
     int width, prec, type = SNV_INT, count_or_errorcode = SNV_OK;
     unsigned flags, *pdollar;
     char pad, buffer[256], *p, *end;
-    boolean is_negative;
+    boolean is_negative = FALSE;
 
     return_val_if_fail(pparser != NULL, SNV_ERROR);
 
@@ -630,8 +634,11 @@ format_number (pparser, stream, ppformat, argv, pargc,
     return_val_if_fail((width >= 0) && (prec >= 0), SNV_ERROR);
 
     /* Ensure that the type flags are propogated to the caller. */
-    if (**ppformat == 'u')
-    {
+    switch (**ppformat) {
+    case 'u':
+    case 'x':
+    case 'X':
+    case 'o':
 	type |= SNV_FLAG_UNSIGNED;
     }
     if (ISSET(flags, SNV_FLAG_LONG))
@@ -643,7 +650,7 @@ format_number (pparser, stream, ppformat, argv, pargc,
     pdollar = (unsigned*)parser_data_get(pparser, "dollar");
     if (argv != NULL)
     {
-	if (**ppformat == 'u')
+	if (type & SNV_FLAG_UNSIGNED)
 	{
 	    if (pdollar != NULL)
 	    {
